RunOptions

Struct RunOptions 

pub struct RunOptions<'a> {
    pub run_dir: Option<&'a Path>,
    pub resume_state: Option<ResumeState>,
    pub resume_already_completed: bool,
    pub agent_cmd: Option<String>,
    pub stage_dir: Option<PathBuf>,
    pub execution_log_path: Option<PathBuf>,
}
Options for run_compiled_graph.

Fields

run_dir: Option<&'a Path>

If set, used to derive execution log path when Self::execution_log_path is set (e.g. run_dir/execution.log.json).

resume_state: Option<ResumeState>

If set, run resumes from this state (from execution log only, no checkpoint.json).

resume_already_completed: bool

When true and Self::resume_state is set, skip running and return already_completed (e.g. from execution log with finished_at).

agent_cmd: Option<String>

Command for agent/codergen nodes (e.g. cursor-agent). Required if the graph has codergen nodes.

stage_dir: Option<PathBuf>

Directory for agent staging.

execution_log_path: Option<PathBuf>

If set, execution log is written to this path after the run (success or failure).