pub struct RunOptions<'a> {
pub run_dir: Option<&'a Path>,
pub agent_cmd: Option<String>,
pub stage_dir: Option<PathBuf>,
pub execution_log_path: Option<PathBuf>,
}Expand description
Options for run_compiled_graph.
Fields
run_dir: Option<&'a Path>If set, checkpoint is written here at successful exit (to run_dir/checkpoint.json).
agent_cmd: Option<String>Command for agent/codergen nodes (e.g. cursor-agent). Required if the graph has codergen nodes.
stage_dir: Option<PathBuf>Directory for agent outcome.json and staging.
execution_log_path: Option<PathBuf>If set, execution steps are recorded and written to this path as execution.log.json (on success and failure).